@@ -1,5 +1,6 @@
 import asyncio
 import random
+import socket
 
 import pytest
 
@@ -8,14 +9,12 @@ from aiomcache.pool import Connection, MemcachePool
 from .conftest import McacheParams
 
 
-@pytest.mark.asyncio
 async def test_pool_creation(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=1, maxsize=5, **mcache_params)
     assert pool.size() == 0
     assert pool._minsize == 1
 
 
-@pytest.mark.asyncio
 async def test_pool_acquire_release(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=1, maxsize=5, **mcache_params)
     conn = await pool.acquire()
@@ -25,7 +24,6 @@ async def test_pool_acquire_release(mcache_params: McacheParams) -> None:
     await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_pool_acquire_release2(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=1, maxsize=5, **mcache_params)
     reader, writer = await asyncio.open_connection(
@@ -42,7 +40,6 @@ async def test_pool_acquire_release2(mcache_params: McacheParams) -> None:
     await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_pool_clear(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=1, maxsize=5, **mcache_params)
     conn = await pool.acquire()
@@ -52,7 +49,6 @@ async def test_pool_clear(mcache_params: McacheParams) -> None:
     assert pool._pool.qsize() == 0
 
 
-@pytest.mark.asyncio
 async def test_acquire_dont_create_new_connection_if_have_conn_in_pool(
     mcache_params: McacheParams,
 ) -> None:
@@ -72,7 +68,6 @@ async def test_acquire_dont_create_new_connection_if_have_conn_in_pool(
     await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_acquire_limit_maxsize(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=1, maxsize=1, **mcache_params)
     assert pool.size() == 0
@@ -98,7 +93,6 @@ async def test_acquire_limit_maxsize(mcache_params: McacheParams) -> None:
     await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_acquire_task_cancellation(mcache_params: McacheParams) -> None:
 
     class TestClient(Client):
@@ -127,30 +121,29 @@ async def test_acquire_task_cancellation(mcache_params: McacheParams) -> None:
     await client._pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_maxsize_greater_than_minsize(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=5, maxsize=1, **mcache_params)
     conn = await pool.acquire()
     assert isinstance(conn.reader, asyncio.StreamReader)
     assert isinstance(conn.writer, asyncio.StreamWriter)
     pool.release(conn)
+    await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_0_minsize(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=0, maxsize=5, **mcache_params)
     conn = await pool.acquire()
     assert isinstance(conn.reader, asyncio.StreamReader)
     assert isinstance(conn.writer, asyncio.StreamWriter)
     pool.release(conn)
+    await pool.clear()
 
 
-@pytest.mark.asyncio
 async def test_bad_connection(mcache_params: McacheParams) -> None:
     pool = MemcachePool(minsize=5, maxsize=1, **mcache_params)
     pool._host = "INVALID_HOST"
     assert pool.size() == 0
-    with pytest.raises(Exception):
+    with pytest.raises(socket.gaierror):
         conn = await pool.acquire()
         assert isinstance(conn.reader, asyncio.StreamReader)
         assert isinstance(conn.writer, asyncio.StreamWriter)
